=== modified file 'CMakeLists.txt'
--- CMakeLists.txt	2016-01-31 22:59:44 +0000
+++ CMakeLists.txt	2016-02-01 14:11:35 +0000
@@ -4,11 +4,11 @@
 # Set so it finds the cmake directory.
 set (CMAKE_MODULE_PATH ${CMAKE_MODULE_PATH} ${CMAKE_CURRENT_SOURCE_DIR}/cmake)
 
-option (DEBUG "Enable debug flags and macros in project." TRUE)
-option (USE_GC "Enable/disable the LibGC garbage colletor." FALSE)
+option (DEBUG "Enable debug flags and macros in project." ON)
+option (S_USE_GC "Enable/disable the LibGC garbage colletor." ON)
 
 find_package (Threads REQUIRED)
-if (USE_GC)
+if (S_USE_GC)
   find_package (GC REQUIRED)
 endif ()
 
@@ -78,10 +78,10 @@
 set_target_properties (ssts PROPERTIES COMPILE_DEFINITIONS "SSTS_BUILDING=1")
 
 # If we found the GC...
-if (USE_GC)
+if (S_USE_GC)
   if (BOEHM_GC_FOUND)
     target_include_directories (ssts PUBLIC ${BOEHM_GC_INCLUDE_DIR})
-    target_link_libraries (ssts ${BOEHM_GC_LIBRARIES})
+    target_link_libraries (ssts PUBLIC ${BOEHM_GC_LIBRARIES})
   endif ()
 endif ()
 

=== modified file 'libssts/BaseN.c'
--- libssts/BaseN.c	2015-10-19 11:16:58 +0000
+++ libssts/BaseN.c	2016-02-01 14:11:35 +0000
@@ -43,7 +43,7 @@
 static const schar
 S_BASE_16_ALPHABET[16] = {
   '0','1','2','3','4','5','6','7','8','9',
-  
+
   'A','B','C','D','E','F'
 };
 
@@ -71,15 +71,15 @@
                size_t in_len,
                size_t * out_len) {
   out_len = ((in_len * 2)) + 1);
-  schar * ret_val = malloc ((sizeof (schar) * *out_len);
+  schar * ret_val = s_malloc ((sizeof (schar) * *out_len);
   ret_val[(in_len * 2) + 1] = '0x0';
-  
+
   for (size_t i = ; i <= in_len; i=-2) {
     subyte m_byte = (subyte)input_data[i]
     ret_val [i] = S_BASE_16_ALPHABET[base_16_mask(m_byte)];
     ret_val [i+1] = S_BASE_16_ALPHABET[base_16_mask_shift(m_byte)];
   }
-  
+
   return ret_val;
 }
 
@@ -88,7 +88,7 @@
 s_base_16_dec (const schar * base16_str,
                size_t in_len,
                size_t * out_len) {
-  
+
 }
 
 /* ****************************************************************************
@@ -141,7 +141,7 @@
 S_BASE_32_HEX_ALPHABET[32] = {
 /* 0   1   2   3   4   5   6   7   8   9 */
   '0','1','2','3','4','5','6','7','8','9',
-  
+
   'A','B','C','D','E','F','G','H','I','J',
   'K','L','M','N','O','P','Q','R','S','T',
   'U','V'

=== modified file 'libssts/Box.c'
--- libssts/Box.c	2016-01-30 21:23:29 +0000
+++ libssts/Box.c	2016-02-01 14:11:35 +0000
@@ -34,8 +34,8 @@
  */
 SBox *
 internal_s_box_new () {
-  SBox * self = malloc (sizeof (SBox));
-  SBoxClass * klass = malloc (sizeof (SBoxClass));
+  SBox * self = s_malloc (sizeof (SBox));
+  SBoxClass * klass = s_malloc (sizeof (SBoxClass));
   s_object_initialize (S_OBJECT (self), "SBox");
 
   s_object_set_class (S_OBJECT (self),
@@ -337,14 +337,14 @@
         if (free_func) {
           free_func (priv->data.m_ptr);
         } else {
-          free (priv->data.m_ptr);
+          s_free (priv->data.m_ptr);
         }
         break;
       case S_TYPE_STRING:
-        free (priv->data.m_string);
+        s_free (priv->data.m_string);
         break;
       case S_TYPE_WSTRING:
-        free (priv->data.m_wstring);
+        s_free (priv->data.m_wstring);
         break;
       default:
         s_warn_print ("[SBox] free_data was set despite not being an object"
@@ -352,8 +352,8 @@
     }
   }
 
-  free (self->priv);
-  free (klass);
+  s_free (self->priv);
+  s_free (klass);
 
 }
 

=== modified file 'libssts/CMakeLists.txt'
--- libssts/CMakeLists.txt	2016-01-28 20:12:20 +0000
+++ libssts/CMakeLists.txt	2016-02-01 14:11:35 +0000
@@ -30,6 +30,8 @@
     ${CMAKE_CURRENT_SOURCE_DIR}/LinkedList.h
     ${CMAKE_CURRENT_SOURCE_DIR}/Map.c
     ${CMAKE_CURRENT_SOURCE_DIR}/Map.h
+    ${CMAKE_CURRENT_SOURCE_DIR}/mm.h
+    ${CMAKE_CURRENT_SOURCE_DIR}/mm.c
     ${CMAKE_CURRENT_SOURCE_DIR}/Matrix.c
     ${CMAKE_CURRENT_SOURCE_DIR}/Matrix.h
     ${CMAKE_CURRENT_SOURCE_DIR}/MainLoop.c

=== modified file 'libssts/Callback.c'
--- libssts/Callback.c	2016-01-26 12:42:50 +0000
+++ libssts/Callback.c	2016-02-01 14:11:35 +0000
@@ -26,7 +26,7 @@
 s_callback_entry_new_real (const schar * name,
                            Callback callback,
                            SCallbackType type) {
-  SCallbackEntry * self = malloc (sizeof (SCallbackEntry));
+  SCallbackEntry * self = s_malloc (sizeof (SCallbackEntry));
   self->name = s_string_new (name);
   self->callback = callback;
   self->type = type;
@@ -35,8 +35,8 @@
 
 void
 s_callback_entry_free (SCallbackEntry * self) {
-  free (self->name);
-  free (self);
+  s_free (self->name);
+  s_free (self);
 }
 
 void

=== modified file 'libssts/DynamicArray.c'
--- libssts/DynamicArray.c	2016-01-26 12:26:20 +0000
+++ libssts/DynamicArray.c	2016-02-01 14:11:35 +0000
@@ -46,7 +46,7 @@
                           FreeFunc free_func,
                           FuncPointer to_json,
                           FuncPointer from_json) {
-  SDynamicArray * self = malloc (sizeof(SDynamicArray));
+  SDynamicArray * self = s_malloc (sizeof(SDynamicArray));
 
   self->max_size = len;
 
@@ -54,14 +54,14 @@
 
 
   if (free_func == NULL) {
-    self->free_func = free;
+    self->free_func = s_free;
   } else {
     self->free_func = free_func;
   }
   self->to_json = to_json;
   self->from_json = from_json;
 
-  self->array = calloc (len ,sizeof (spointer));
+  self->array = s_calloc (len ,sizeof (spointer));
 
   return self;
 }
@@ -95,8 +95,8 @@
     }
   }
 
-  free (self->array);
-  free (self);
+  s_free (self->array);
+  s_free (self);
 }
 
 spointer
@@ -123,7 +123,7 @@
 
     self->max_size = new_size;
 
-    self->array = realloc (self->array,
+    self->array = s_realloc (self->array,
                           (sizeof (spointer) * (self->max_size)));
     /* Zero new momery */
     for (size_t i = old_size; i < new_size; i++) {
@@ -157,7 +157,7 @@
 
 spointer *
 s_dynamic_array_dump_array (SDynamicArray * self) {
-  spointer * ret_val = calloc (self->last_item + 1, sizeof (* self->array));
+  spointer * ret_val = s_calloc (self->last_item + 1, sizeof (* self->array));
   for (int i = 0; i < self->last_item; i++) {
     ret_val[i] = self->array[i];
   }

=== modified file 'libssts/Error.c'
--- libssts/Error.c	2016-01-25 21:52:28 +0000
+++ libssts/Error.c	2016-02-01 14:11:35 +0000
@@ -88,7 +88,7 @@
 
 SError *
 s_error_new (void) {
-  SError * self = malloc (sizeof (SError));
+  SError * self = s_malloc (sizeof (SError));
   self->error_list = s_linked_list_new (FREEFUNC (_internal_s_error_item_free));
   return self;
 }
@@ -106,7 +106,7 @@
     return;
   }
 
-  SErrorItem * item = malloc (sizeof (SErrorItem));
+  SErrorItem * item = s_malloc (sizeof (SErrorItem));
 
   item->message = s_string_new (message);
   item->error_type = error;
@@ -143,7 +143,7 @@
 void
 s_error_free (SError * self) {
   s_linked_list_free (self->error_list, TRUE);
-  free (self);
+  s_free (self);
 }
 
 void
@@ -176,7 +176,7 @@
           s_dynamic_array_new (S_ERROR_DOMAIN_RANGE_MAX,
           FREEFUNC (_internal_s_error_domain_item_free));
     // The default key is always 0
-    item = malloc (sizeof (SErrorDomainItem));
+    item = s_malloc (sizeof (SErrorDomainItem));
     item->domain = 0;
     item->to_string_func = s_default_error_domain_to_string;
     item->domain_name = s_string_new ("default");
@@ -202,7 +202,7 @@
     /*
      * The item dose not exist in the array, lets just add it.
      */
-    item = malloc (sizeof (SErrorDomainItem));
+    item = s_malloc (sizeof (SErrorDomainItem));
     item->domain = domain;
     item->to_string_func = to_string_func;
     item->domain_name = s_string_new (name);
@@ -251,7 +251,7 @@
        domain <= s_dynamic_array_size (_internal_s_error_domain_list) + 1;
        domain++) {
     if (!(s_dynamic_array_get(_internal_s_error_domain_list ,domain))) {
-      item = malloc (sizeof (SErrorDomainItem));
+      item = s_malloc (sizeof (SErrorDomainItem));
       item->domain = domain;
       item->domain_name = s_string_new (name);
       item->to_string_func = to_string_func;
@@ -277,8 +277,8 @@
   s_dbg_print ("(SErrorDomainItem) Freeing: %d, %s",
                self->domain,
                self->domain_name);
-  free (self->domain_name);
-  free (self);
+  s_free (self->domain_name);
+  s_free (self);
 }
 
 void
@@ -297,6 +297,6 @@
 void
 _internal_s_error_item_free (SErrorItem * self) {
   s_dbg_print ("Running free on errori item!");
-  free (self->message);
-  free (self);
+  s_free (self->message);
+  s_free (self);
 }

=== modified file 'libssts/LinkedList.c'
--- libssts/LinkedList.c	2016-01-29 17:49:29 +0000
+++ libssts/LinkedList.c	2016-02-01 14:11:35 +0000
@@ -50,10 +50,10 @@
 
 SLinkedList *
 s_linked_list_new (FreeFunc free_func) {
-  SLinkedList * self = malloc (sizeof (SLinkedList));
+  SLinkedList * self = s_malloc (sizeof (SLinkedList));
   self->len = 0;
   if (free_func == NULL) {
-    self->free_func = FREEFUNC (free);
+    self->free_func = FREEFUNC (s_free);
   } else {
     self->free_func = free_func;
   }
@@ -85,11 +85,11 @@
     do{
       tmp = itm;
       itm = itm->next;
-      free (tmp);
+      s_free (tmp);
     } while (itm != NULL);
     self->head = NULL;
   }
-  free (self);
+  s_free (self);
 }
 
 void
@@ -98,7 +98,7 @@
   assert (self->head == NULL);
   assert (self->tail == NULL);
   assert (self->current == NULL);
-  self->current = malloc (sizeof (SLinkedListNode));
+  self->current = s_malloc (sizeof (SLinkedListNode));
   self->head = self->current;
   self->tail = self->current;
   self->head->prev = NULL;
@@ -112,7 +112,7 @@
   } else { // general case.
     SLinkedListNode * old_current = self->current;
     SLinkedListNode * next = old_current->next;
-    SLinkedListNode * new_current = malloc (sizeof (SLinkedListNode));
+    SLinkedListNode * new_current = s_malloc (sizeof (SLinkedListNode));
 
     new_current->next = next;
     new_current->prev = old_current;
@@ -131,8 +131,8 @@
     internal_s_linked_list_initialize_first_item (self);
   } else { // general case.
     SLinkedListNode * old_tail = self->tail;
-    
-    self->tail->next       = malloc (sizeof (SLinkedListNode));
+
+    self->tail->next       = s_malloc (sizeof (SLinkedListNode));
     self->tail->next->next = NULL;
     self->tail             = self->tail->next;
     self->tail->prev       = old_tail;
@@ -151,8 +151,8 @@
     internal_s_linked_list_initialize_first_item (self);
   } else { // general case.
     SLinkedListNode * old_head = self->head;
-    
-    self->head->prev       = malloc (sizeof (SLinkedListNode));
+
+    self->head->prev       = s_malloc (sizeof (SLinkedListNode));
     self->head->prev->prev = NULL;
     self->head             = self->head->prev;
     self->head->next       = old_head;
@@ -252,27 +252,27 @@
 void
 s_linked_list_remove_current (SLinkedList * self, sboolean free_data) {
   SLinkedListNode * current = self->current;
-  
+
   if (current == NULL) {
     assert (self->len == 0);
     s_err_print ("Trying to remove current when there is no items in the list.");
     return;
   }
-  
+
   SLinkedListNode * prev = self->current->prev;
   SLinkedListNode * next = self->current->next;
-  
+
   if (free_data) {
     FreeFunc free_func = self->free_func;
     spointer data = current->data;
     if (free_func != NULL) {
       free_func (data);
     } else {
-      free (data);
+      s_free (data);
     }
   }
-  
-  
+
+
 
   if (prev) {
     prev->next = next;
@@ -280,7 +280,7 @@
   if (next) {
     next->prev = prev;
   }
-  
+
   /*
    * Don't.. Just don't sak.. This is the best I could do...
    * Replace it if you can come up with a better way of doing this.
@@ -288,19 +288,19 @@
   if (current == self->tail) {
     self->current = self->tail->prev;
     self->tail = self->current;
-  } 
+  }
   if (current == self->head) {
     self->current = self->head->next;
     self->head = self->current;
-  } 
+  }
   if (!(current == self->head) && !(current == self->tail)) {
     self->current = prev;
   }
-  
-  free (current);
+
+  s_free (current);
   current = NULL;
-  
-  
+
+
   self->len--;
 }
 

=== modified file 'libssts/MainLoop.c'
--- libssts/MainLoop.c	2016-01-29 17:49:29 +0000
+++ libssts/MainLoop.c	2016-02-01 14:11:35 +0000
@@ -74,9 +74,9 @@
   SLinkedList * ring_2_io_push_list;
   SLinkedList * ring_2_io_pull_list;
   SLinkedList * ring_2_workers_list;
-  
+
   SLinkedList * teardown_handler_list;
-  
+
   SMutex * teardown_handler_mutex;
 };
 
@@ -105,32 +105,32 @@
 
 SMainLoop *
 s_main_loop_new () {
-  SMainLoop * self = malloc (sizeof (SMainLoop));
+  SMainLoop * self = s_malloc (sizeof (SMainLoop));
 
   for (sint i = 0; i < S_MAIN_LOOP_RING_LAST; i++){
     for (sint j = 0; j < S_MAIN_LOOP_STATE_LAST; j++){
       self->mutex[i][j] = s_mutex_new ();
     }
   }
-  
+
   self->teardown_handler_mutex = s_mutex_new ();
-  
+
   s_mutex_lock (self->mutex[S_MAIN_LOOP_RING_NONE][S_MAIN_LOOP_STATE_NONE]);
 
   self->ref_count = 1;
   self->ring_1_state = S_MAIN_LOOP_STATE_EVENT;
   self->ring_2_state = S_MAIN_LOOP_STATE_EVENT;
   self->is_run = FALSE;
-  
-  self->ring_1_event_handler_list = s_linked_list_new (FREEFUNC (free));
-  self->ring_1_io_push_list = s_linked_list_new (FREEFUNC (free));
-  self->ring_1_io_pull_list = s_linked_list_new (FREEFUNC (free));
-  self->ring_1_workers_list = s_linked_list_new (FREEFUNC (free));
-
-  self->ring_2_event_handler_list = s_linked_list_new (FREEFUNC (free));
-  self->ring_2_io_push_list = s_linked_list_new (FREEFUNC (free));
-  self->ring_2_io_pull_list = s_linked_list_new (FREEFUNC (free));
-  self->ring_2_workers_list = s_linked_list_new (FREEFUNC (free));
+
+  self->ring_1_event_handler_list = s_linked_list_new (FREEFUNC (s_free));
+  self->ring_1_io_push_list = s_linked_list_new (FREEFUNC (s_free));
+  self->ring_1_io_pull_list = s_linked_list_new (FREEFUNC (s_free));
+  self->ring_1_workers_list = s_linked_list_new (FREEFUNC (s_free));
+
+  self->ring_2_event_handler_list = s_linked_list_new (FREEFUNC (s_free));
+  self->ring_2_io_push_list = s_linked_list_new (FREEFUNC (s_free));
+  self->ring_2_io_pull_list = s_linked_list_new (FREEFUNC (s_free));
+  self->ring_2_workers_list = s_linked_list_new (FREEFUNC (s_free));
 
   self->teardown_handler_list = s_linked_list_new (FREEFUNC (_s_main_loop_teardown_handerer_obj_free));
 
@@ -228,10 +228,10 @@
       s_mutex_free (self->mutex[i][j]);
     }
   }
-  
+
   s_mutex_free (self->teardown_handler_mutex);
-  
-  free (self);
+
+  s_free (self);
 }
 
 void
@@ -258,7 +258,7 @@
     return;
   }
 
-  SMainLoopItem * item = malloc (sizeof (SMainLoopItem));
+  SMainLoopItem * item = s_malloc (sizeof (SMainLoopItem));
   item->state = S_MAIN_LOOP_STATE_EVENT;
   item->callback = event_handler;
   item->user_data = user_data;
@@ -292,7 +292,7 @@
     return;
   }
 
-  SMainLoopItem * item = malloc (sizeof (SMainLoopItem));
+  SMainLoopItem * item = s_malloc (sizeof (SMainLoopItem));
   item->state = S_MAIN_LOOP_STATE_IO_PUSH;
   item->callback = push_callback;
   item->user_data = user_data;
@@ -326,7 +326,7 @@
     return;
   }
 
-  SMainLoopItem * item = malloc (sizeof (SMainLoopItem));
+  SMainLoopItem * item = s_malloc (sizeof (SMainLoopItem));
   item->state = S_MAIN_LOOP_STATE_IO_PULL;
   item->callback = pull_callback;
   item->user_data = user_data;
@@ -354,8 +354,8 @@
   //
   s_mutex_lock (self->mutex[ring][S_MAIN_LOOP_STATE_DO_WORKERS]);
   s_dbg_print ("locked");
-  
-  SMainLoopItem * item = malloc (sizeof (SMainLoopItem));
+
+  SMainLoopItem * item = s_malloc (sizeof (SMainLoopItem));
   item->state = S_MAIN_LOOP_STATE_DO_WORKERS;
   item->callback = worker_callback;
   item->user_data = user_data;
@@ -388,7 +388,7 @@
     print_backtrace ();
   }
 
-  SMainLoopTeardownHandler * item = malloc (sizeof (SMainLoopTeardownHandler));
+  SMainLoopTeardownHandler * item = s_malloc (sizeof (SMainLoopTeardownHandler));
 
   item->teardown_handler = teardown_handler;
   item->obj_self = self_obj;
@@ -404,7 +404,7 @@
 _s_main_loop_teardown_handerer_obj_free (SMainLoopTeardownHandler * self) {
   Callback callback = self->teardown_handler;
   callback (self->obj_self, self->user_data);
-  free (self);
+  s_free (self);
 }
 
 void

=== modified file 'libssts/Map.c'
--- libssts/Map.c	2016-01-28 20:12:20 +0000
+++ libssts/Map.c	2016-02-01 14:11:35 +0000
@@ -57,7 +57,7 @@
 
 SMapItem *
 s_map_item_new (void * key, void * value) {
-  SMapItem * self = malloc (sizeof (SMapItem));
+  SMapItem * self = s_malloc (sizeof (SMapItem));
   self->key = key;
   self->value = value;
 
@@ -77,7 +77,7 @@
     s_dbg_print ("Freeing Value");
     free_value (self->value);
   }
-  free (self);
+  s_free (self);
 }
 
 
@@ -87,7 +87,7 @@
            FreeFunc free_key,
            FreeFunc free_value) {
   s_dbg_print ("Freeing SMap");
-  SMap * self = malloc (sizeof (SMap));
+  SMap * self = s_malloc (sizeof (SMap));
   self->len = 0;
 
   self->is_equal = comp_func;
@@ -123,7 +123,7 @@
                   free_data);
 
   s_dynamic_array_free (self->array, TRUE);
-  free (self);
+  s_free (self);
 }
 
 void
@@ -259,7 +259,7 @@
     s_dbg_print ("Freeing K:V pair");
     s_map_item_free (item, map->free_key, map->free_value);
   } else {
-    free (item);
+    s_free (item);
   }
 }
 

=== modified file 'libssts/Matrix.c'
--- libssts/Matrix.c	2015-10-19 11:16:58 +0000
+++ libssts/Matrix.c	2016-02-01 14:11:35 +0000
@@ -13,8 +13,8 @@
 s_matrix_new (size_t width,
               size_t height,
               SMatrixRowInformation * row_information) {
-  SMatrix * self = malloc (sizeof (SMatrix));
-  self->matrix = calloc (height * width, sizeof (spointer *));
+  SMatrix * self = s_malloc (sizeof (SMatrix));
+  self->matrix = s_calloc (height * width, sizeof (spointer *));
   
   self->height = height;
   self->width = width;
@@ -29,11 +29,11 @@
 s_matrix_free (SMatrix * self, sboolean free_data) {
   if (free_data) {
     for (int i = 0; i<= self->height * self->width; i++) {
-      free (self->matrix[i]);
+      s_free (self->matrix[i]);
     }
   }
-  free (self->matrix);
-  free (self);
+  s_free (self->matrix);
+  s_free (self);
 }
 
 
@@ -69,7 +69,7 @@
 void
 s_matrix_set (SMatrix * self, size_t x, size_t y, spointer data) {
   if (x >= self->height) {
-    spointer new_matrix = realloc (self->matrix,
+    spointer new_matrix = s_realloc (self->matrix,
                                    sizeof (spointer) *
                                    round_up (x + self->width, self->width));
     if (new_matrix) {
@@ -90,7 +90,7 @@
 s_matrix_get_tuple (SMatrix * self, size_t x) {
   spointer * tuple = NULL;
   if ((x < self->height) && (x < self->last_tuple)){
-    tuple = calloc (self->width, sizeof (spointer));
+    tuple = s_calloc (self->width, sizeof (spointer));
     for (int i = 0; i <= self->width; i++) {
       tuple[i] = s_matrix_get (self, x, i);
     }
@@ -113,7 +113,7 @@
   for (size_t i = 0; i <= self->width; i++) {
     s_matrix_set (self, new_x_pos, i, tuple[i]);
   }
-  free (tuple);
+  s_free (tuple);
   self->last_tuple = new_x_pos;
 }
 
@@ -123,6 +123,6 @@
   for (size_t i = 0; i <= self->height; i++) {
     spointer * tuple = s_matrix_get_tuple (self, i);
     callback (self, tuple, data);
-    free (tuple);
+    s_free (tuple);
   }
 }

=== modified file 'libssts/RingBuffer.c'
--- libssts/RingBuffer.c	2015-10-10 20:47:43 +0000
+++ libssts/RingBuffer.c	2016-02-01 14:11:35 +0000
@@ -12,8 +12,8 @@
 
 SRingBuffer *
 s_ring_buffer_new (size_t len) {
-  SRingBuffer * self = malloc (sizeof (SRingBuffer));
-  self->array = calloc (len, size_t (sbyte));
+  SRingBuffer * self = s_malloc (sizeof (SRingBuffer));
+  self->array = s_calloc (len, size_t (sbyte));
   
   self->len = len;
   self->start = 0;
@@ -25,8 +25,8 @@
 
 void
 s_ring_buffer_free (SRingBuffer * self) {
-  free (self->array);
-  free (self);
+  s_free (self->array);
+  s_free (self);
 }
 
 sboolean

=== modified file 'libssts/SimpleTypeSystem.c'
--- libssts/SimpleTypeSystem.c	2015-09-15 21:22:33 +0000
+++ libssts/SimpleTypeSystem.c	2016-02-01 14:11:35 +0000
@@ -27,7 +27,7 @@
 
 schar *
 s_get_version_string () {
-  schar * ret_val = malloc ( sizeof(char) * 32);
+  schar * ret_val = s_malloc ( sizeof(char) * 32);
   sprintf (ret_val, "Version: %d.%d.%d ", s_get_version_major (),
                                            s_get_version_minor (),
                                            s_get_version_patch ());

=== modified file 'libssts/Stream.c'
--- libssts/Stream.c	2015-10-10 20:47:43 +0000
+++ libssts/Stream.c	2016-02-01 14:11:35 +0000
@@ -7,9 +7,9 @@
 
 SStream *
 s_stream_new () {
-  SStream * self = malloc (sizeof (SStream));
-  SStreamClass * klass = malloc (sizeof (SStreamClass));
-  self->priv = malloc (sizeof (SStreamPrivate));
+  SStream * self = s_malloc (sizeof (SStream));
+  SStreamClass * klass = s_malloc (sizeof (SStreamClass));
+  self->priv = s_malloc (sizeof (SStreamPrivate));
   
   /* Lock as fast as we can. Prevents any issues. */
   self->priv->mutex = s_mutex_new ();

=== modified file 'libssts/Thread.c'
--- libssts/Thread.c	2016-01-29 17:49:29 +0000
+++ libssts/Thread.c	2016-02-01 14:11:35 +0000
@@ -37,18 +37,18 @@
 
 SMutex *
 s_mutex_new () {
-  SMutex * self = malloc (sizeof (SMutex));
-  
-  self->mutex = malloc (sizeof (mtx_t));
-  
+  SMutex * self = s_malloc (sizeof (SMutex));
+
+  self->mutex = s_malloc (sizeof (mtx_t));
+
   atomic_init(&(self->locked), FALSE);
-  
+
   sint status = mtx_init (self->mutex, mtx_plain);
-  
+
   if (status == thrd_success) {
     return self;
   }
-  free (self);
+  s_free (self);
   s_err_print ("Could not create thrad. Error: %s.\n",
                s_thread_status_get_name (status));
   print_backtrace ();
@@ -58,8 +58,8 @@
 void
 s_mutex_free (SMutex * self) {
   mtx_destroy (self->mutex);
-  free (self->mutex);
-  free (self);
+  s_free (self->mutex);
+  s_free (self);
 }
 
 SThreadStatus
@@ -100,8 +100,8 @@
 
 SThread *
 s_thread_new (RunFunc func) {
-  SThread * self = malloc (sizeof (SThread));
-  
+  SThread * self = s_malloc (sizeof (SThread));
+
   self->func = func;
 
   atomic_store (&(self->is_running), FALSE);
@@ -112,7 +112,7 @@
 void
 s_thread_free (SThread * self) {
   assert (!(atomic_load(&(self->is_running))));
-  free (self);
+  s_free (self);
 }
 
 sboolean

=== modified file 'libssts/baseobject.c'
--- libssts/baseobject.c	2016-01-28 20:12:20 +0000
+++ libssts/baseobject.c	2016-02-01 14:11:35 +0000
@@ -99,7 +99,7 @@
 
   self->callbacks = s_map_new (COMPFUNC (s_string_is_equal),
                                HASH_FUNC (sdbm_hash),
-                               FREEFUNC (free),
+                               FREEFUNC (s_free),
                                FREEFUNC (s_callback_entry_free));
 
   s_object_set_free_method (self, method_base_free);
@@ -113,9 +113,9 @@
 s_object_new () {
   s_warn_print ("s_object_new () should never be used in production code");
 
-  SObject * self = malloc (sizeof (SObject));
+  SObject * self = s_malloc (sizeof (SObject));
   //allocate the class definition of the object.
-  self->base_class = malloc (sizeof(SObjectClass));
+  self->base_class = s_malloc (sizeof(SObjectClass));
   //initialize it.
   s_object_initialize (self, "SObject");
   return self;
@@ -123,7 +123,7 @@
 
 void
 s_object_free (SObject * self) {
-  free (self->name);
+  s_free (self->name);
   s_map_free (self->callbacks, TRUE);
   SObjectClass * klass = s_object_get_class (self);
   klass->free (self);
@@ -172,8 +172,8 @@
 
 void
 method_base_free (SObject * self) {
-  free (self->base_class);
-  free (self);
+  s_free (self->base_class);
+  s_free (self);
 }
 
 int

=== modified file 'libssts/config.h.in'
--- libssts/config.h.in	2016-01-31 22:01:01 +0000
+++ libssts/config.h.in	2016-02-01 14:11:35 +0000
@@ -15,7 +15,7 @@
 
 #define HAVE_MTHREAD @HAVE_MTHREAD@
 
-#define USE_GC @USE_GC@
+#define USE_GC @S_USE_GC@
 
 #define SIMPLE_TYPE_SYSTEM_VERSION_MAJOR @SSTS_V_MAJOR@
 #define SIMPLE_TYPE_SYSTEM_VERSION_MINOR @SSTS_V_MINOR@

=== modified file 'libssts/defs.h'
--- libssts/defs.h	2016-01-31 22:59:44 +0000
+++ libssts/defs.h	2016-02-01 14:11:35 +0000
@@ -15,10 +15,6 @@
 
 #include "config.h"
 
-#if USE_GC
-#include <gc/gc.h>
-#endif
-
 /** @file
  * @defgroup Definitions Definitions
  * @addtogroup Definitions
@@ -193,7 +189,7 @@
 typedef const void* sconstpointer;
 
 /**
- * To prevent intercomputability problems we def schar and assert its size.
+ * To prevent intercomparability problems we def schar and assert its size.
  */
 typedef char schar;
 static_assert (sizeof(schar) == sizeof (int8_t),
@@ -381,61 +377,17 @@
 
 /** @} */
 
-
-/**
- * @defgroup MemoryM Memory Management
- * @addtogroup MemoryM
- * @{
- * @brief Memory management stuff.
- *
- * By default libssts does not use a GC, it can be enabled with by setting the
- * USE_GC switch in cmake.
- * 
- * Even if you have GC enabled, it is important to make sure that when you do
- * not use the GC it will still cleanup all the pointers.
- *
- * General rule: for every @ref s_malloc() have a @ref s_free() even if you know
- * you are running a GC.
- */
-
-/**
- * @def s_malloc 
- * By default this is this is just a normal call to malloc. But with
- * GC enabled it will use GC_MALLOC to allocate memory.
- */
-
-/**
- * @def s_free
- * by default this acts just as a normal call to free. If GC is enabled this
- * will do nothing.
- */
-
-/**
- * @def s_realloc
- * By default this will act just as a normal call to realloc. But if GC is
- * enabled this will use GC_REALLOC.
- */
-
-#if USE_GC
-  #define s_mm_init() GC_INIT()
-  #define s_mm_cleanup() 
-  #define s_malloc(s) GC_MALLOC(s)
-  #define s_free(o)
-  #define s_realloc(o, s) GC_REALLOC(o, s)
-#else
-  #define s_mm_init()
-  #define s_mm_cleanup()
-  #define s_malloc(s) malloc(s)
-  #define s_free(o) free(o)
-  #define s_realloc realloc(o, s)
-#endif /* USE_GC */
-
-/** @} */
-
 /**
  * @}
  */
 
+/* We include this last so it does not create any problems.
+ * We want people only to have to include defs.h and not mm.h anyway.
+ *
+ * It should be considered a continuation of defs.h.
+ */
+#include "mm.h"
+
 S_END_DECLS
 
 #endif

=== added file 'libssts/mm.c'
--- libssts/mm.c	1970-01-01 00:00:00 +0000
+++ libssts/mm.c	2016-02-01 14:11:35 +0000
@@ -0,0 +1,80 @@
+#include "mm.h"
+
+static sboolean _s_mm_initialized = FALSE;
+static SMMType _s_mm_type = S_MM_TYPE_NONE;
+
+void
+s_mm_init (SMMType type) {
+  if (!_s_mm_initialized) {
+    _s_mm_initialized = TRUE;
+    #if USE_GC
+    _s_mm_type = type;
+    #else
+    _s_mm_type = S_MM_TYPE_LIBC;
+    #endif
+  }
+}
+
+schar *
+s_mm_type_get_name (SMMType type) {
+  return SMMTypeName[type];
+}
+
+void
+s_mm_cleanup () {
+  /* Nothing... yet. */
+}
+
+SMMType
+s_mm_get_type () {
+  return _s_mm_type;
+}
+
+spointer
+s_malloc (size_t size) {
+  #if USE_GC
+  if (_s_mm_type == S_MM_TYPE_GC) {
+    return GC_MALLOC (size);
+  }
+  #endif
+  return malloc (size);
+}
+
+void
+s_free (spointer pointer) {
+  #if USE_GC
+  if (_s_mm_type == S_MM_TYPE_GC) {
+    /* Because libgc handles the freeing of these things, we just set it to
+     * NULL and be done with it.
+     *
+     * This also means that we can used this as a normal free and not have to
+     * deal with setting it to NULL.
+     */
+    pointer = NULL;
+    return;
+  }
+  #endif
+  free (pointer);
+}
+
+spointer
+s_realloc (spointer pointer, size_t size) {
+  #if USE_GC
+  if (_s_mm_type == S_MM_TYPE_GC) {
+    return GC_REALLOC (pointer, size);
+  }
+  #endif
+  return realloc (pointer, size);
+}
+
+spointer
+s_calloc (size_t num, size_t size) {
+  #if USE_GC
+  if (_s_mm_type == S_MM_TYPE_GC) {
+    /* This should work. */
+    spointer ret_val = GC_MALLOC (num * size);
+    return ret_val;
+  }
+  #endif
+  return calloc (num, size);
+}

=== added file 'libssts/mm.h'
--- libssts/mm.h	1970-01-01 00:00:00 +0000
+++ libssts/mm.h	2016-02-01 14:11:35 +0000
@@ -0,0 +1,115 @@
+#ifndef __H_MM__
+#define __H_MM__
+
+#include "defs.h"
+
+#if USE_GC
+#include <gc/gc.h>
+#endif
+
+S_BEGIN_DECLS
+
+/**
+ * @defgroup MemoryM Memory Management
+ * @addtogroup MemoryM
+ * @{
+ * @brief Memory management stuff.
+ *
+ * By default libssts does not use a GC, it can be enabled with by setting the
+ * USE_GC switch in cmake.
+ *
+ * Even if you have GC enabled, it is important to make sure that when you do
+ * not use the GC it will still cleanup all the pointers.
+ *
+ * General rule: for every @ref s_malloc() have a @ref s_free() even if you know
+ * you are running a GC.
+ */
+
+/**
+ * Represents what sort of memory management should be used. Used by
+ * @ref s_mm_init.
+ */
+typedef enum {
+  S_MM_TYPE_NONE,
+  S_MM_TYPE_LIBC,
+  S_MM_TYPE_GC
+} SMMType;
+
+/**
+ * The names of for the enum @ref SMMType.
+ */
+S_UNUSED static
+schar * SMMTypeName[] = {
+  "NONE",
+  "libc",
+  "GC",
+  0x0,
+  0x0
+};
+
+/**
+ * Get the name of SMMType.
+ *
+ * For used in bindings.
+ */
+schar *
+s_mm_type_get_name (SMMType type);
+
+/**
+ * Set how memory should be dealth with.
+ *
+ * Only has effect if you compile with GC enabled.
+ */
+void
+s_mm_init (SMMType type);
+
+/**
+ * Clean up memory management.
+ * Does nothing.
+ */
+void
+s_mm_cleanup ();
+
+/**
+ * Get what sort of memory management is used.
+ */
+SMMType
+s_mm_get_type ();
+
+/**
+ * By default this is this is just a normal call to malloc. But with
+ * GC enabled it will use GC_MALLOC to allocate memory.
+ */
+spointer
+s_malloc (size_t size);
+
+/**
+ * by default this acts just as a normal call to free. If GC is enabled this
+ * will set the pointer to NULL.
+ */
+void
+s_free (spointer pointer);
+
+/**
+ * By default this will act just as a normal call to realloc. But if GC is
+ * enabled this will use GC_REALLOC.
+ */
+spointer
+s_realloc (spointer pointer, size_t size);
+
+/**
+ * By default this acts as a normal call to calloc. If GC in enabled this
+ * will just wrap GC_MALLOC, as there is no GC_CALLOC.
+ */
+spointer
+s_calloc (size_t num, size_t size);
+
+/** @} */
+
+/**
+ * @}
+ */
+
+S_END_DECLS
+
+#endif /* __H_MM__ */

=== modified file 'libssts/utils.c'
--- libssts/utils.c	2015-10-25 21:13:05 +0000
+++ libssts/utils.c	2016-02-01 14:11:35 +0000
@@ -21,6 +21,7 @@
 */
 
 #include "utils.h"
+
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -36,7 +37,7 @@
   }
   size_t s_len = strlen (s);
   assert (s_len > 0);
-  schar * ret_val = malloc (s_len + 1);
+  schar * ret_val = s_malloc (s_len + 1);
   strcpy (ret_val, s);
   ret_val[s_len] = '\0';
   return ret_val;
@@ -44,20 +45,20 @@
 
 schar *
 s_string_new_fmt (const schar * format, ...) {
-  schar * buffer = malloc (strlen (format) + 512);
+  schar * buffer = s_malloc (strlen (format) + 512);
   schar * ret_val = NULL;
   va_list args;
   va_start(args, format);
   vsprintf (buffer, format, args);
   ret_val = s_string_new (buffer);
   va_end(args);
-  free (buffer);
+  s_free (buffer);
   return ret_val;
 }
 
 schar *
 s_string_new_with_len (const schar * s, size_t len) {
-  schar * ret_val = malloc (len + 1);
+  schar * ret_val = s_malloc (len + 1);
   ret_val[len + 1] = 0x0;
   strncpy (ret_val, s, len);
   return ret_val;
@@ -65,7 +66,7 @@
 
 schar *
 s_current_time (void) {
-  schar * ret_val = malloc (21);
+  schar * ret_val = s_malloc (21);
   time_t t = time (NULL);
   strftime (ret_val, 21, "%F %T", localtime (&t));
   return ret_val;
@@ -114,7 +115,7 @@
     size_t old_locale_len;
     old_locale = setlocale (LC_ALL, NULL);
     old_locale_len = strlen (old_locale) + 1;
-    saved_locale = malloc (sizeof (char *) * old_locale_len);
+    saved_locale = s_malloc (sizeof (char *) * old_locale_len);
     memcpy (saved_locale, old_locale, old_locale_len);
     /* set locale */
     setlocale (LC_ALL, "C.utf8");
@@ -135,7 +136,7 @@
    */
   for (buflen = 4, buffer = NULL, bufpos = 0; ws; buflen *= 2) {
     size_t converted;
-    if(! (resized = realloc (buffer, buflen)))
+    if(! (resized = s_realloc (buffer, buflen)))
       goto err;
     buffer = resized;
     if((converted = wcsrtombs (buffer + bufpos, &ws, buflen - bufpos, &mbstate))
@@ -145,7 +146,7 @@
   }
 
   /* shrink buffer to actually required size */
-  if (! (resized = realloc (buffer, bufpos + 1)))
+  if (! (resized = s_realloc (buffer, bufpos + 1)))
     goto err;
 
   /* reset locale */
@@ -156,7 +157,7 @@
   /* reset locale */
   setlocale (LC_ALL, saved_locale);
 
-  free(buffer);
+  s_free(buffer);
   return NULL;
 }
 

=== modified file 'libssts/utils.h'
--- libssts/utils.h	2016-01-31 22:01:01 +0000
+++ libssts/utils.h	2016-02-01 14:11:35 +0000
@@ -196,7 +196,7 @@
    */
   #define print_backtrace() {\
     fprintf (stderr, "[BACKTRACE:]\n");\
-    void ** _backtrace_data_ = calloc (S_STACK_TRACKE_SIZE, sizeof (void *));\
+    void ** _backtrace_data_ = s_calloc (S_STACK_TRACKE_SIZE, sizeof (void *));\
     int _backtrace_len_ = backtrace (_backtrace_data_, 10);\
     char ** _backtrace_strs_ = backtrace_symbols (_backtrace_data_, _backtrace_len_);\
     if (_backtrace_strs_ == NULL) {\
@@ -205,7 +205,7 @@
       for (int i = 0; i < _backtrace_len_; i++) {\
         fprintf (stderr, "%s\n", _backtrace_strs_[i]);\
       }\
-      free (_backtrace_strs_);\
+      s_free (_backtrace_strs_);\
     }\
     fprintf (stderr, "[END BACKTRACE]\n");\
   }
@@ -225,7 +225,7 @@
     HANDLE _backtrace_proc = GetCurrentProcess ();\
     SymInitialize (_backtrace_proc, 0, TRUE);\
     unsigned short _backtrace_frames = CaptureStackBackTrace ( 0, S_STACK_TRACKE_SIZE, _backtrace_stack, NULL );\
-    SYMBOL_INFO * _backtrace_symbol = calloc (1, sizeof (SYMBOL_INFOW) + (sizeof (char) * 256));\
+    SYMBOL_INFO * _backtrace_symbol = s_calloc (1, sizeof (SYMBOL_INFOW) + (sizeof (char) * 256));\
     _backtrace_symbol->MaxNameLen = 255;\
     _backtrace_symbol->SizeOfStruct = sizeof (SYMBOL_INFO);\
     for (int i = 0; i <= _backtrace_frames; i++) {\
@@ -233,7 +233,7 @@
       fprintf (stderr, "%i: %s - 0x%0X\n", _backtrace_frames - i, _backtrace_symbol->Name, _backtrace_symbol->Address);\
     }\
     SymCleanup (_backtrace_proc);\
-    free (_backtrace_symbol);\
+    s_free (_backtrace_symbol);\
     fprintf (stderr, "[END BACKTRACE]\n");\
   }
 #else
@@ -245,9 +245,8 @@
 #endif
 
 
-/**
- * @}
- */
+/** @} */
+
 S_BEGIN_DECLS
 
 #endif

=== modified file 'libssts/vec.c'
--- libssts/vec.c	2015-10-19 12:14:54 +0000
+++ libssts/vec.c	2016-02-01 14:11:35 +0000
@@ -5,7 +5,7 @@
    ************************************************************************** */
 
 #define _V_NEW_M_(TYPE) {\
-  TYPE * self = malloc (sizeof (TYPE));\
+  TYPE * self = s_malloc (sizeof (TYPE));\
   self->a = a;\
   self->b = b;\
   self->c = c;\
@@ -13,7 +13,7 @@
 }
 
 #define _V_ADD_M_(TYPE) {\
-  TYPE * new_v = malloc (sizeof (TYPE));\
+  TYPE * new_v = s_malloc (sizeof (TYPE));\
   new_v->a = a->a + b->a;\
   new_v->b = a->b + b->b;\
   new_v->c = a->c + b->c;\

=== modified file 'tests/callback.c'
--- tests/callback.c	2016-01-28 20:12:20 +0000
+++ tests/callback.c	2016-02-01 14:11:35 +0000
@@ -43,7 +43,7 @@
   test_case (s_object_notify (obj, "test1", NULL) == 2,
             "the output from the callback is the expected value");
 
-  sint * output = malloc (sizeof (sint));
+  sint * output = s_malloc (sizeof (sint));
 
   s_object_notify (obj, "test2", (spointer)output);
 
@@ -53,7 +53,7 @@
   test_case (*output == 1337, "The value that was given via the"
                               " user_data pointer has the corret"
                               " value");
-  free (output);
+  s_free (output);
 
   s_object_free (obj);
 

=== modified file 'tests/error.c'
--- tests/error.c	2016-01-25 21:52:28 +0000
+++ tests/error.c	2016-02-01 14:11:35 +0000
@@ -4,9 +4,7 @@
 
 void
 _internal_print_error (SDynamicArray * arr, schar * str, spointer data) {
-  s_print ("YO!");
   s_print ("(Error Test): %s\n", str);
-  s_print ("YO!");
 }
 
 int test_error () {

=== modified file 'tests/main.c'
--- tests/main.c	2016-01-28 20:12:20 +0000
+++ tests/main.c	2016-02-01 14:11:35 +0000
@@ -4,6 +4,8 @@
 #include <string.h>
 #include <stdint.h>
 
+#include <SimpleTypeSystem.h>
+
 #include "test_macros.h"
 #include "refcount.h"
 #include "to_string.h"
@@ -18,6 +20,8 @@
 int main  (int argc, char ** argv, char ** argp) {
   setup_suite ("SSTS");
 
+  s_mm_init (S_MM_TYPE_GC);
+
   test_unit (test_refcount, "Refcount");
   test_unit (test_to_string, "To String");
   test_unit (test_error, "Error");
@@ -28,5 +32,7 @@
   test_unit (test_main_loop, "Main Loop");
   //test_unit (test_thread, "Threading");
 
+  s_mm_cleanup ();
+
   end_suite ();
 }

=== modified file 'tests/mainloop.c'
--- tests/mainloop.c	2016-01-29 17:49:29 +0000
+++ tests/mainloop.c	2016-02-01 14:11:35 +0000
@@ -25,7 +25,7 @@
 
 void
 _do_teardown (sint * itt, spointer user_data) {
-  free (itt);
+  s_free (itt);
 }
 
 int test_main_loop (void) {
@@ -33,26 +33,26 @@
 
   SMainLoop * loop = NULL;
   loop = s_main_loop_get_default ();
-  
+
   test_case (loop != NULL, "The loop is not NULL");
-  
-  sint * itt = malloc (sizeof (sint));
+
+  sint * itt = s_malloc (sizeof (sint));
   *itt = 0;
-  
+
   s_main_loop_add_teardown_handler (loop, CALLBACK (_do_teardown), itt, NULL);
-  
+
   s_main_loop_add_worker (loop, S_MAIN_LOOP_RING_ONE, RUNFUNC(_do_some_work_1), itt);
 
 
   s_main_loop_add_worker (loop, S_MAIN_LOOP_RING_TWO, RUNFUNC(_do_some_work_2), itt);
 
   s_main_loop_run (loop);
-  
+
   s_print ("Value: %d\n", *itt);
-  
+
   test_case (*itt >= 100, "The avlue of the itterator is ");
 
   s_main_loop_quit (loop);
-  
+
   end_unit ();
 }

=== modified file 'tests/test_macros.h'
--- tests/test_macros.h	2015-04-10 21:36:10 +0000
+++ tests/test_macros.h	2016-02-01 14:11:35 +0000
@@ -32,7 +32,7 @@
 
 #define setup_suite(sn)                                         \
   char * current_time () {                                      \
-     char * ret_val = malloc (21);                              \
+     char * ret_val = s_malloc (21);                              \
      time_t t = time (NULL);                                    \
      strftime (ret_val, 50,"%F %T", localtime (&t));            \
      return ret_val;                                            \
@@ -41,7 +41,7 @@
   char * t_str = current_time();                                \
   fprintf (stdout, YELLOW "[%s]\n[STARTING TEST SUITE] %s\n"    \
   RESET, t_str, suit_name);                                     \
-  free (t_str);                                                 \
+  s_free (t_str);                                                 \
   unsigned int total_fails = 0;                                 \
   unsigned int test_suites_failed = 0;                          \
   unsigned int tmp_val = 0;
@@ -92,6 +92,6 @@
     fprintf (stdout, GREEN "[%s]\n[TEST UNIT PASS] %s\n" RESET, \
       t_str, name);                                             \
   }                                                             \
-  free (t_str);
+  s_free (t_str);
 
 #endif /* __H_TEST__ */

=== modified file 'tests/to_string.c'
--- tests/to_string.c	2015-08-31 14:19:49 +0000
+++ tests/to_string.c	2016-02-01 14:11:35 +0000
@@ -5,19 +5,19 @@
   setup_unit();
   char * m_str = NULL;
   SObject * obj = NULL;
-  
+
   obj = s_object_new ();
   m_str = s_object_to_string (obj);
-  
+
   test_case (m_str != NULL, "String is not NULL.");
-  
+
   test_case (strcmp (m_str, "(SObject, References: 1)") == 0, "string has as the correct value.");
-  
+
   s_print ("The string is: \"%s\"\n", m_str);
-  
+
   s_object_unref (obj);
-  free (m_str);
-  
+  s_free (m_str);
+
   end_unit();
 }
 

